[Libreoffice-commits] .: binfilter/bf_forms binfilter/bf_sd binfilter/bf_svx binfilter/bf_sw binfilter/bf_xmloff binfilter/inc
Caolán McNamara
caolan at kemper.freedesktop.org
Wed Mar 30 05:14:45 PDT 2011
binfilter/bf_forms/source/component/Button.hxx | 3 +
binfilter/bf_forms/source/component/CheckBox.hxx | 2 +
binfilter/bf_forms/source/component/Columns.hxx | 2 +
binfilter/bf_forms/source/component/ComboBox.hxx | 4 ++
binfilter/bf_forms/source/component/Date.hxx | 3 +
binfilter/bf_forms/source/component/Edit.hxx | 4 ++
binfilter/bf_forms/source/component/EditBase.hxx | 2 +
binfilter/bf_forms/source/component/File.hxx | 4 ++
binfilter/bf_forms/source/component/FormComponent.hxx | 2 +
binfilter/bf_forms/source/component/FormattedField.hxx | 6 +++
binfilter/bf_forms/source/component/FormsCollection.hxx | 2 +
binfilter/bf_forms/source/component/Grid.hxx | 5 +++
binfilter/bf_forms/source/component/Hidden.hxx | 3 +
binfilter/bf_forms/source/component/Image.hxx | 5 +++
binfilter/bf_forms/source/component/ImageButton.hxx | 2 +
binfilter/bf_forms/source/component/ImageControl.hxx | 6 +++
binfilter/bf_forms/source/component/ListBox.hxx | 4 ++
binfilter/bf_forms/source/component/RadioButton.hxx | 3 +
binfilter/bf_forms/source/component/Time.hxx | 3 +
binfilter/bf_forms/source/inc/InterfaceContainer.hxx | 3 +
binfilter/bf_sd/source/ui/unoidl/sd_unoobj.cxx | 2 -
binfilter/bf_svx/source/editeng/editundo.hxx | 25 +++++-----------
binfilter/bf_svx/source/form/svx_siimport.cxx | 2 +
binfilter/bf_svx/source/inc/fmobj.hxx | 1
binfilter/bf_svx/source/inc/fmshimp.hxx | 1
binfilter/bf_svx/source/unodraw/svx_unoshap2.cxx | 2 -
binfilter/bf_svx/source/unodraw/svx_unoshap3.cxx | 2 -
binfilter/bf_svx/source/unodraw/svx_unoshap4.cxx | 2 -
binfilter/bf_svx/source/unodraw/svx_unoshape.cxx | 17 +---------
binfilter/bf_sw/source/core/crsr/sw_crsrsh.cxx | 2 -
binfilter/bf_sw/source/core/inc/dflyobj.hxx | 4 ++
binfilter/bf_sw/source/filter/xml/sw_xmlitemi.cxx | 1
binfilter/bf_xmloff/source/draw/xmloff_ximpstyl.cxx | 1
binfilter/inc/bf_sc/rangenam.hxx | 1
binfilter/inc/bf_sc/stlpool.hxx | 1
binfilter/inc/bf_sch/ChXChartDocument.hxx | 3 +
binfilter/inc/bf_sch/axisobj.hxx | 4 ++
binfilter/inc/bf_sch/chmod3d.hxx | 10 ++++++
binfilter/inc/bf_sch/chtscene.hxx | 3 +
binfilter/inc/bf_sch/schgroup.hxx | 3 +
binfilter/inc/bf_sch/stlpool.hxx | 1
binfilter/inc/bf_sd/stlpool.hxx | 1
binfilter/inc/bf_sfx2/plugobj.hxx | 1
binfilter/inc/bf_svx/cube3d.hxx | 2 +
binfilter/inc/bf_svx/dlight3d.hxx | 2 +
binfilter/inc/bf_svx/editund2.hxx | 1
binfilter/inc/bf_svx/extrud3d.hxx | 2 +
binfilter/inc/bf_svx/label3d.hxx | 2 +
binfilter/inc/bf_svx/lathe3d.hxx | 2 +
binfilter/inc/bf_svx/light3d.hxx | 2 +
binfilter/inc/bf_svx/obj3d.hxx | 4 ++
binfilter/inc/bf_svx/plight3d.hxx | 2 +
binfilter/inc/bf_svx/pntobj3d.hxx | 2 +
binfilter/inc/bf_svx/polygn3d.hxx | 2 +
binfilter/inc/bf_svx/polyob3d.hxx | 2 +
binfilter/inc/bf_svx/polysc3d.hxx | 2 +
binfilter/inc/bf_svx/scene3d.hxx | 2 +
binfilter/inc/bf_svx/sphere3d.hxx | 2 +
binfilter/inc/bf_svx/svdocapt.hxx | 1
binfilter/inc/bf_svx/svdocirc.hxx | 1
binfilter/inc/bf_svx/svdoedge.hxx | 1
binfilter/inc/bf_svx/svdogrp.hxx | 1
binfilter/inc/bf_svx/svdomeas.hxx | 1
binfilter/inc/bf_svx/svdoole2.hxx | 1
binfilter/inc/bf_svx/svdopage.hxx | 1
binfilter/inc/bf_svx/svdopath.hxx | 1
binfilter/inc/bf_svx/svdorect.hxx | 1
binfilter/inc/bf_svx/svdotext.hxx | 1
binfilter/inc/bf_svx/svdouno.hxx | 1
binfilter/inc/bf_svx/svdovirt.hxx | 1
binfilter/inc/bf_svx/unoshape.hxx | 4 +-
binfilter/inc/bf_sw/dcontact.hxx | 3 +
72 files changed, 168 insertions(+), 40 deletions(-)
New commits:
commit 0f332824b9e760a8b7da673c8b16963b28bbace7
Author: Caolán McNamara <caolanm at redhat.com>
Date: Wed Mar 30 12:45:04 2011 +0100
silence warnings by enforcing the current reality
diff --git a/binfilter/bf_forms/source/component/Button.hxx b/binfilter/bf_forms/source/component/Button.hxx
index 3b84f23..7356334 100644
--- a/binfilter/bf_forms/source/component/Button.hxx
+++ b/binfilter/bf_forms/source/component/Button.hxx
@@ -111,6 +111,9 @@ public:
// ::com::sun::star::lang::XEventListener
virtual void SAL_CALL disposing(const ::com::sun::star::lang::EventObject& _rSource) throw(::com::sun::star::uno::RuntimeException)
{ OControl::disposing(_rSource); }
+
+ using OImageControl::disposing;
+
private:
DECL_LINK( OnClick, void* );
};
diff --git a/binfilter/bf_forms/source/component/CheckBox.hxx b/binfilter/bf_forms/source/component/CheckBox.hxx
index 21a360c..488f549 100644
--- a/binfilter/bf_forms/source/component/CheckBox.hxx
+++ b/binfilter/bf_forms/source/component/CheckBox.hxx
@@ -99,6 +99,8 @@ public:
protected:
virtual void SAL_CALL disposing();
+ using OBoundControlModel::disposing;
+ using OPropertySetHelper::getFastPropertyValue;
protected:
void implConstruct();
diff --git a/binfilter/bf_forms/source/component/Columns.hxx b/binfilter/bf_forms/source/component/Columns.hxx
index 32c62bd..8f03406 100644
--- a/binfilter/bf_forms/source/component/Columns.hxx
+++ b/binfilter/bf_forms/source/component/Columns.hxx
@@ -112,6 +112,8 @@ public:
throw(::com::sun::star::lang::IllegalArgumentException);
virtual void SAL_CALL setFastPropertyValue_NoBroadcast(sal_Int32 nHandle, const ::com::sun::star::uno::Any& rValue) throw (::com::sun::star::uno::Exception);
+ using OPropertySetAggregationHelper::getFastPropertyValue;
+
// ::com::sun::star::beans::XPropertyState
virtual ::com::sun::star::beans::PropertyState getPropertyStateByHandle(sal_Int32 nHandle);
virtual void setPropertyToDefaultByHandle(sal_Int32 nHandle);
diff --git a/binfilter/bf_forms/source/component/ComboBox.hxx b/binfilter/bf_forms/source/component/ComboBox.hxx
index 70215e3..4b317a8 100644
--- a/binfilter/bf_forms/source/component/ComboBox.hxx
+++ b/binfilter/bf_forms/source/component/ComboBox.hxx
@@ -113,6 +113,10 @@ public:
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rProps,
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rAggregateProps
) const;
+
+ using OBoundControlModel::disposing;
+ using OPropertySetHelper::getFastPropertyValue;
+
IMPLEMENT_INFO_SERVICE()
protected:
diff --git a/binfilter/bf_forms/source/component/Date.hxx b/binfilter/bf_forms/source/component/Date.hxx
index e0ceeff..057641d 100644
--- a/binfilter/bf_forms/source/component/Date.hxx
+++ b/binfilter/bf_forms/source/component/Date.hxx
@@ -79,6 +79,9 @@ public:
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rProps,
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rAggregateProps
) const;
+
+ using OPropertySetHelper::getFastPropertyValue;
+
IMPLEMENT_INFO_SERVICE()
protected:
diff --git a/binfilter/bf_forms/source/component/Edit.hxx b/binfilter/bf_forms/source/component/Edit.hxx
index f6163b3..05fe17e 100644
--- a/binfilter/bf_forms/source/component/Edit.hxx
+++ b/binfilter/bf_forms/source/component/Edit.hxx
@@ -94,6 +94,10 @@ public:
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rProps,
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rAggregateProps
) const;
+
+ using OBoundControlModel::disposing;
+ using OPropertySetHelper::getFastPropertyValue;
+
IMPLEMENT_INFO_SERVICE()
protected:
diff --git a/binfilter/bf_forms/source/component/EditBase.hxx b/binfilter/bf_forms/source/component/EditBase.hxx
index 8358418..d888bf8 100644
--- a/binfilter/bf_forms/source/component/EditBase.hxx
+++ b/binfilter/bf_forms/source/component/EditBase.hxx
@@ -98,6 +98,8 @@ protected:
virtual sal_Int16 getPersistenceFlags() const;
// derived classes may use this if they want this base class to write additinal version flags
// (one of the PF_.... constants). After ::read they may ask for that flags with getLastReadVersion
+
+ using OPropertySetHelper::getFastPropertyValue;
};
//.........................................................................
diff --git a/binfilter/bf_forms/source/component/File.hxx b/binfilter/bf_forms/source/component/File.hxx
index 831ad43..8f9d185 100644
--- a/binfilter/bf_forms/source/component/File.hxx
+++ b/binfilter/bf_forms/source/component/File.hxx
@@ -89,6 +89,10 @@ public:
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rProps,
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rAggregateProps
) const;
+
+ using OControlModel::disposing;
+ using OPropertySetHelper::getFastPropertyValue;
+
IMPLEMENT_INFO_SERVICE()
protected:
diff --git a/binfilter/bf_forms/source/component/FormComponent.hxx b/binfilter/bf_forms/source/component/FormComponent.hxx
index a87e2b6..5a17e39 100644
--- a/binfilter/bf_forms/source/component/FormComponent.hxx
+++ b/binfilter/bf_forms/source/component/FormComponent.hxx
@@ -292,6 +292,7 @@ public:
throw (::com::sun::star::lang::IllegalArgumentException);
virtual void SAL_CALL setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const ::com::sun::star::uno::Any& rValue )
throw (::com::sun::star::uno::Exception);
+ using ::cppu::OPropertySetHelper::getFastPropertyValue;
// ::com::sun::star::beans::XPropertyState
virtual ::com::sun::star::beans::PropertyState getPropertyStateByHandle(sal_Int32 nHandle);
@@ -457,6 +458,7 @@ public:
throw (::com::sun::star::lang::IllegalArgumentException);
virtual void SAL_CALL setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const ::com::sun::star::uno::Any& rValue )
throw (::com::sun::star::uno::Exception);
+ using ::cppu::OPropertySetHelper::getFastPropertyValue;
// XEventListener
virtual void SAL_CALL disposing(const ::com::sun::star::lang::EventObject& Source) throw (::com::sun::star::uno::RuntimeException);
diff --git a/binfilter/bf_forms/source/component/FormattedField.hxx b/binfilter/bf_forms/source/component/FormattedField.hxx
index 4520b64..efb6a86 100644
--- a/binfilter/bf_forms/source/component/FormattedField.hxx
+++ b/binfilter/bf_forms/source/component/FormattedField.hxx
@@ -132,6 +132,10 @@ namespace frm
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rProps,
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rAggregateProps
) const;
+
+ using OBoundControlModel::disposing;
+ using OPropertySetHelper::getFastPropertyValue;
+
IMPLEMENT_INFO_SERVICE()
// XPropertyChangeListener
@@ -179,6 +183,8 @@ namespace frm
// ::com::sun::star::awt::XControl
virtual void SAL_CALL setDesignMode(sal_Bool bOn) throw ( ::com::sun::star::uno::RuntimeException);
+ using OControl::disposing;
+
private:
DECL_LINK( OnKeyPressed, void* );
};
diff --git a/binfilter/bf_forms/source/component/FormsCollection.hxx b/binfilter/bf_forms/source/component/FormsCollection.hxx
index c253690..750e7a2 100644
--- a/binfilter/bf_forms/source/component/FormsCollection.hxx
+++ b/binfilter/bf_forms/source/component/FormsCollection.hxx
@@ -88,6 +88,8 @@ public:
// ::com::sun::star::container::XChild
virtual ::comphelper::InterfaceRef SAL_CALL getParent() throw(::com::sun::star::uno::RuntimeException);
virtual void SAL_CALL setParent(const ::comphelper::InterfaceRef& Parent) throw(::com::sun::star::lang::NoSupportException, ::com::sun::star::uno::RuntimeException);
+
+ using OInterfaceContainer::disposing;
};
//.........................................................................
diff --git a/binfilter/bf_forms/source/component/Grid.hxx b/binfilter/bf_forms/source/component/Grid.hxx
index e610f5a..0bff5d2 100644
--- a/binfilter/bf_forms/source/component/Grid.hxx
+++ b/binfilter/bf_forms/source/component/Grid.hxx
@@ -181,6 +181,11 @@ public:
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rProps,
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rAggregateProps
) const;
+
+ // prevent method hiding
+ using OControlModel::disposing;
+ using OControlModel::getFastPropertyValue;
+
IMPLEMENT_INFO_SERVICE()
protected:
diff --git a/binfilter/bf_forms/source/component/Hidden.hxx b/binfilter/bf_forms/source/component/Hidden.hxx
index a6e6fdd..0da0bef 100644
--- a/binfilter/bf_forms/source/component/Hidden.hxx
+++ b/binfilter/bf_forms/source/component/Hidden.hxx
@@ -76,6 +76,9 @@ public:
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rProps,
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rAggregateProps
) const;
+
+ using OPropertySetHelper::getFastPropertyValue;
+
IMPLEMENT_INFO_SERVICE()
protected:
diff --git a/binfilter/bf_forms/source/component/Image.hxx b/binfilter/bf_forms/source/component/Image.hxx
index 014c427..3e19ab2 100644
--- a/binfilter/bf_forms/source/component/Image.hxx
+++ b/binfilter/bf_forms/source/component/Image.hxx
@@ -128,6 +128,9 @@ public:
virtual void SAL_CALL removeConsumer( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XImageConsumer >& xConsumer ) throw (::com::sun::star::uno::RuntimeException);
virtual void SAL_CALL startProduction( ) throw (::com::sun::star::uno::RuntimeException);
+ using OControlModel::disposing;
+ using OPropertySetHelper::getFastPropertyValue;
+
protected:
void implConstruct();
@@ -181,6 +184,8 @@ public:
// ::com::sun::star::beans::XPropertyChangeListener
virtual void SAL_CALL propertyChange( const ::com::sun::star::beans::PropertyChangeEvent& ) throw(::com::sun::star::uno::RuntimeException);
+ using OControl::disposing;
+
protected:
::com::sun::star::uno::Reference< ::com::sun::star::frame::XModel > getXModel(const InterfaceRef& xIface) const;
diff --git a/binfilter/bf_forms/source/component/ImageButton.hxx b/binfilter/bf_forms/source/component/ImageButton.hxx
index 45efa99..0c0877f 100644
--- a/binfilter/bf_forms/source/component/ImageButton.hxx
+++ b/binfilter/bf_forms/source/component/ImageButton.hxx
@@ -99,6 +99,8 @@ public:
virtual void SAL_CALL disposing(const ::com::sun::star::lang::EventObject& _rSource) throw(::com::sun::star::uno::RuntimeException)
{ OControl::disposing(_rSource); }
+ using OImageControl::disposing;
+
// ::com::sun::star::awt::XMouseListener
virtual void SAL_CALL mousePressed(const ::com::sun::star::awt::MouseEvent& /*e*/) throw ( ::com::sun::star::uno::RuntimeException);
virtual void SAL_CALL mouseReleased(const ::com::sun::star::awt::MouseEvent& /*e*/) throw ( ::com::sun::star::uno::RuntimeException) { }
diff --git a/binfilter/bf_forms/source/component/ImageControl.hxx b/binfilter/bf_forms/source/component/ImageControl.hxx
index 63e2b57..81ac3a4 100644
--- a/binfilter/bf_forms/source/component/ImageControl.hxx
+++ b/binfilter/bf_forms/source/component/ImageControl.hxx
@@ -125,6 +125,10 @@ public:
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rProps,
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rAggregateProps
) const;
+
+ using OBoundControlModel::disposing;
+ using OPropertySetHelper::getFastPropertyValue;
+
IMPLEMENT_INFO_SERVICE()
protected:
@@ -167,6 +171,8 @@ public:
// ::com::sun::star::awt::XControl
virtual void SAL_CALL createPeer(const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XToolkit>& _rToolkit, const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindowPeer>& _rParent) throw(::com::sun::star::uno::RuntimeException);
+ using OControl::disposing;
+
private:
void implClearGraphics();
void implInsertGraphics();
diff --git a/binfilter/bf_forms/source/component/ListBox.hxx b/binfilter/bf_forms/source/component/ListBox.hxx
index bec2a42..aeaad0d 100644
--- a/binfilter/bf_forms/source/component/ListBox.hxx
+++ b/binfilter/bf_forms/source/component/ListBox.hxx
@@ -128,6 +128,10 @@ public:
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rProps,
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rAggregateProps
) const;
+
+ using OBoundControlModel::disposing;
+ using OPropertySetHelper::getFastPropertyValue;
+
IMPLEMENT_INFO_SERVICE()
protected:
diff --git a/binfilter/bf_forms/source/component/RadioButton.hxx b/binfilter/bf_forms/source/component/RadioButton.hxx
index ee92db8..d4014c9 100644
--- a/binfilter/bf_forms/source/component/RadioButton.hxx
+++ b/binfilter/bf_forms/source/component/RadioButton.hxx
@@ -92,6 +92,9 @@ public:
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rProps,
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rAggregateProps
) const;
+
+ using OPropertySetHelper::getFastPropertyValue;
+
IMPLEMENT_INFO_SERVICE()
protected:
diff --git a/binfilter/bf_forms/source/component/Time.hxx b/binfilter/bf_forms/source/component/Time.hxx
index 57c89fb..e6b2e03 100644
--- a/binfilter/bf_forms/source/component/Time.hxx
+++ b/binfilter/bf_forms/source/component/Time.hxx
@@ -79,6 +79,9 @@ public:
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rProps,
::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property >& /* [out] */ _rAggregateProps
) const;
+
+ using OPropertySetHelper::getFastPropertyValue;
+
IMPLEMENT_INFO_SERVICE()
protected:
diff --git a/binfilter/bf_forms/source/inc/InterfaceContainer.hxx b/binfilter/bf_forms/source/inc/InterfaceContainer.hxx
index 3d7f081..8976939 100644
--- a/binfilter/bf_forms/source/inc/InterfaceContainer.hxx
+++ b/binfilter/bf_forms/source/inc/InterfaceContainer.hxx
@@ -285,6 +285,9 @@ public:
// ::com::sun::star::form::XFormComponent
virtual ::comphelper::InterfaceRef SAL_CALL getParent() throw(::com::sun::star::uno::RuntimeException);
virtual void SAL_CALL setParent(const ::comphelper::InterfaceRef& Parent) throw(::com::sun::star::lang::NoSupportException, ::com::sun::star::uno::RuntimeException);
+
+ // XEventListener
+ using OInterfaceContainer::disposing;
};
//.........................................................................
} // namespace frm
diff --git a/binfilter/bf_sd/source/ui/unoidl/sd_unoobj.cxx b/binfilter/bf_sd/source/ui/unoidl/sd_unoobj.cxx
index 9f3d7d7..4cf5808 100644
--- a/binfilter/bf_sd/source/ui/unoidl/sd_unoobj.cxx
+++ b/binfilter/bf_sd/source/ui/unoidl/sd_unoobj.cxx
@@ -232,7 +232,7 @@ uno::Any SAL_CALL SdXShape::queryAggregation( const uno::Type & rType )
throw(uno::RuntimeException)
{
uno::Any aAny;
- mpShape->queryAggregation( rType, aAny );
+ mpShape->tryQueryAggregation( rType, aAny );
return aAny;
}
diff --git a/binfilter/bf_svx/source/editeng/editundo.hxx b/binfilter/bf_svx/source/editeng/editundo.hxx
index 99ef040..4f5da12 100644
--- a/binfilter/bf_svx/source/editeng/editundo.hxx
+++ b/binfilter/bf_svx/source/editeng/editundo.hxx
@@ -63,6 +63,8 @@ public:
virtual void Redo();
virtual void Repeat();
+ using SfxUndoAction::Repeat;
+
virtual BOOL Merge( SfxUndoAction *pNextAction );
};
@@ -87,11 +89,9 @@ public:
virtual void Undo();
virtual void Redo();
virtual void Repeat();
-};
-// -----------------------------------------------------------------------
-// EditUndoMoveParagraphs
-// ------------------------------------------------------------------------
+ using SfxUndoAction::Repeat;
+};
// -----------------------------------------------------------------------
// EditUndoSetStyleSheet
@@ -117,6 +117,8 @@ public:
virtual void Undo();
virtual void Redo();
virtual void Repeat();
+
+ using SfxUndoAction::Repeat;
};
// -----------------------------------------------------------------------
@@ -136,20 +138,9 @@ public:
virtual void Undo();
virtual void Redo();
virtual void Repeat();
-};
-
-// -----------------------------------------------------------------------
-// EditUndoSetAttribs
-// ------------------------------------------------------------------------
-
-// -----------------------------------------------------------------------
-// EditUndoTransliteration
-// ------------------------------------------------------------------------
-
-// -----------------------------------------------------------------------
-// EditUndoMarkSelection
-// ------------------------------------------------------------------------
+ using SfxUndoAction::Repeat;
+};
}//end of namespace binfilter
#endif // _EDITUNDO_HXX
diff --git a/binfilter/bf_svx/source/form/svx_siimport.cxx b/binfilter/bf_svx/source/form/svx_siimport.cxx
index 9274ecd..9118615 100644
--- a/binfilter/bf_svx/source/form/svx_siimport.cxx
+++ b/binfilter/bf_svx/source/form/svx_siimport.cxx
@@ -75,6 +75,8 @@ class SiImportRect : public SdrRectObj
public:
SiImportRect();
+ using SdrRectObj::operator=;
+
virtual void ReadData(const SdrObjIOHeader& rHead, SvStream& rIn);
};
diff --git a/binfilter/bf_svx/source/inc/fmobj.hxx b/binfilter/bf_svx/source/inc/fmobj.hxx
index 3c217ae..38918a4 100644
--- a/binfilter/bf_svx/source/inc/fmobj.hxx
+++ b/binfilter/bf_svx/source/inc/fmobj.hxx
@@ -77,6 +77,7 @@ protected:
public:
virtual ~FmFormObj();
+ using SdrRectObj::operator=;
virtual void SetPage(SdrPage* pNewPage);
virtual sal_uInt32 GetObjInventor() const;
diff --git a/binfilter/bf_svx/source/inc/fmshimp.hxx b/binfilter/bf_svx/source/inc/fmshimp.hxx
index 0bddc0f..47b67b5 100644
--- a/binfilter/bf_svx/source/inc/fmshimp.hxx
+++ b/binfilter/bf_svx/source/inc/fmshimp.hxx
@@ -130,6 +130,7 @@ typedef ::cppu::WeakComponentImplHelper6< ::com::sun::star::sdbc::XRowSetListene
//========================================================================
class FmXFormShell_Base_Disambiguation : public FmXFormShell_BD_BASE
{
+ using ::com::sun::star::beans::XPropertyChangeListener::disposing;
protected:
FmXFormShell_Base_Disambiguation( ::osl::Mutex& _rMutex );
virtual void SAL_CALL disposing();
diff --git a/binfilter/bf_svx/source/unodraw/svx_unoshap2.cxx b/binfilter/bf_svx/source/unodraw/svx_unoshap2.cxx
index 74b2b7b..080e555 100644
--- a/binfilter/bf_svx/source/unodraw/svx_unoshap2.cxx
+++ b/binfilter/bf_svx/source/unodraw/svx_unoshap2.cxx
@@ -122,7 +122,7 @@ uno::Any SAL_CALL SvxShapeGroup::queryAggregation( const uno::Type & rType )
else QUERYINT( container::XIndexAccess );
else QUERYINT( container::XElementAccess );
else
- SvxShape::queryAggregation( rType, aAny );
+ SvxShape::tryQueryAggregation( rType, aAny );
return aAny;
}
diff --git a/binfilter/bf_svx/source/unodraw/svx_unoshap3.cxx b/binfilter/bf_svx/source/unodraw/svx_unoshap3.cxx
index 6cbbbac..2cfbb9f 100644
--- a/binfilter/bf_svx/source/unodraw/svx_unoshap3.cxx
+++ b/binfilter/bf_svx/source/unodraw/svx_unoshap3.cxx
@@ -95,7 +95,7 @@ uno::Any SAL_CALL Svx3DSceneObject::queryAggregation( const uno::Type & rType )
else QUERYINT( container::XIndexAccess );
else QUERYINT( container::XElementAccess );
else
- SvxShape::queryAggregation( rType, aAny );
+ SvxShape::tryQueryAggregation( rType, aAny );
return aAny;
}
diff --git a/binfilter/bf_svx/source/unodraw/svx_unoshap4.cxx b/binfilter/bf_svx/source/unodraw/svx_unoshap4.cxx
index e4c2f8d..2b4fd63 100644
--- a/binfilter/bf_svx/source/unodraw/svx_unoshap4.cxx
+++ b/binfilter/bf_svx/source/unodraw/svx_unoshap4.cxx
@@ -75,7 +75,7 @@ SvxOle2Shape::~SvxOle2Shape() throw()
::com::sun::star::uno::Any SAL_CALL SvxOle2Shape::queryAggregation( const ::com::sun::star::uno::Type & rType ) throw(::com::sun::star::uno::RuntimeException)
{
Any aAny;
- SvxShape::queryAggregation( rType, aAny );
+ SvxShape::tryQueryAggregation( rType, aAny );
return aAny;
}
diff --git a/binfilter/bf_svx/source/unodraw/svx_unoshape.cxx b/binfilter/bf_svx/source/unodraw/svx_unoshape.cxx
index f9d20aa..8a4b863 100644
--- a/binfilter/bf_svx/source/unodraw/svx_unoshape.cxx
+++ b/binfilter/bf_svx/source/unodraw/svx_unoshape.cxx
@@ -125,19 +125,6 @@ const SfxItemPropertyMap* ImplGetSvxTextPortionPropertyMap()
sal_Bool ConvertGDIMetaFileToWMF( const GDIMetaFile & rMTF, SvStream & rTargetStream, FilterConfigItem* pConfigItem = NULL, sal_Bool bPlaceable = sal_True );
uno::Reference< uno::XInterface > SAL_CALL SvxUnoGluePointAccess_createInstance( SdrObject* pObject );
-#define GET_TEXT_INTERFACE( xint, xval ) \
- Reference< xint > xval; \
- if(!xTextAgg.is() ) { Reference< ::com::sun::star::text::XText > xText( (OWeakObject*)this, UNO_QUERY ); } \
- if(xTextAgg.is() ) \
- { \
- uno::Any aAny( \
- xTextAgg->queryAggregation( ::getCppuType((const Reference< xint >*)0))); \
- aAny >>= xval; \
- } \
-
-#define INTERFACE_TYPE( xint ) \
- ::getCppuType((const Reference< xint >*)0)
-
/***********************************************************************
* class SvxShape *
***********************************************************************/
@@ -219,7 +206,7 @@ void SvxShape::setMaster( SvxShapeMaster* pMaster )
}
//----------------------------------------------------------------------
-sal_Bool SvxShape::queryAggregation( const ::com::sun::star::uno::Type & rType, ::com::sun::star::uno::Any& aAny )
+sal_Bool SvxShape::tryQueryAggregation( const ::com::sun::star::uno::Type & rType, ::com::sun::star::uno::Any& aAny )
{
if( mpImpl->mpMaster )
{
@@ -3650,7 +3637,7 @@ uno::Any SAL_CALL SvxShapeText::queryAggregation( const uno::Type & rType )
{
uno::Any aAny;
- if( !SvxShape::queryAggregation( rType, aAny ) )
+ if( !SvxShape::tryQueryAggregation( rType, aAny ) )
SvxUnoTextBase::queryAggregation( rType, aAny );
return aAny;
diff --git a/binfilter/bf_sw/source/core/crsr/sw_crsrsh.cxx b/binfilter/bf_sw/source/core/crsr/sw_crsrsh.cxx
index 37fe8e2..75e5d96 100644
--- a/binfilter/bf_sw/source/core/crsr/sw_crsrsh.cxx
+++ b/binfilter/bf_sw/source/core/crsr/sw_crsrsh.cxx
@@ -606,7 +606,7 @@ using namespace ::com::sun::star::util;
/*N*/ {
/*N*/ USHORT nWhich = pOld ? pOld->Which()
/*N*/ : pNew ? pNew->Which()
-/*N*/ : RES_MSG_BEGIN;
+/*N*/ : sal::static_int_cast<USHORT>(RES_MSG_BEGIN);
/*N*/ if( bCallChgLnk &&
/*N*/ ( nWhich < RES_MSG_BEGIN || nWhich >= RES_MSG_END ||
/*N*/ nWhich == RES_FMT_CHG || nWhich == RES_UPDATE_ATTR ||
diff --git a/binfilter/bf_sw/source/core/inc/dflyobj.hxx b/binfilter/bf_sw/source/core/inc/dflyobj.hxx
index 3137bf2..16c4f44 100644
--- a/binfilter/bf_sw/source/core/inc/dflyobj.hxx
+++ b/binfilter/bf_sw/source/core/inc/dflyobj.hxx
@@ -56,6 +56,8 @@ public:
SwFlyDrawObj();
~SwFlyDrawObj();
+ using SdrObject::operator=;
+
// ItemSet access
@@ -80,6 +82,8 @@ public:
SwVirtFlyDrawObj(SdrObject& rNew, SwFlyFrm* pFly);
~SwVirtFlyDrawObj();
+ using SdrObject::operator=;
+
//Ueberladene Methoden der Basisklasse SdrVirtObj
//Wir nehemen die Groessenbehandlung vollstaendig selbst in die Hand.
diff --git a/binfilter/bf_sw/source/filter/xml/sw_xmlitemi.cxx b/binfilter/bf_sw/source/filter/xml/sw_xmlitemi.cxx
index 637b617..40c301f 100644
--- a/binfilter/bf_sw/source/filter/xml/sw_xmlitemi.cxx
+++ b/binfilter/bf_sw/source/filter/xml/sw_xmlitemi.cxx
@@ -146,6 +146,7 @@ public:
const SvXMLUnitConverter& rInUnitConv );
virtual ~SwXMLItemSetContext_Impl();
+ using SvXMLItemSetContext::CreateChildContext;
virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nInPrefix,
const OUString& rLocalName,
const Reference< xml::sax::XAttributeList > & xAttrList,
diff --git a/binfilter/bf_xmloff/source/draw/xmloff_ximpstyl.cxx b/binfilter/bf_xmloff/source/draw/xmloff_ximpstyl.cxx
index 34ee50e..5be3df3 100644
--- a/binfilter/bf_xmloff/source/draw/xmloff_ximpstyl.cxx
+++ b/binfilter/bf_xmloff/source/draw/xmloff_ximpstyl.cxx
@@ -80,6 +80,7 @@ public:
virtual ~SdXMLDrawingPagePropertySetContext();
+ using SvXMLPropertySetContext::CreateChildContext;
virtual SvXMLImportContext *CreateChildContext( USHORT nInPrefix,
const ::rtl::OUString& rLocalName,
const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList >& xAttrList,
diff --git a/binfilter/inc/bf_sc/rangenam.hxx b/binfilter/inc/bf_sc/rangenam.hxx
index e0f7d56..9e616ae 100644
--- a/binfilter/inc/bf_sc/rangenam.hxx
+++ b/binfilter/inc/bf_sc/rangenam.hxx
@@ -179,6 +179,7 @@ public:
ScRangeName(const ScRangeName& rScRangeName, ScDocument* pDocument);
+ using Collection::Clone;
virtual DataObject* Clone(ScDocument* pDoc_) const
{ return new ScRangeName(*this, pDoc_); }
ScRangeData* operator[]( const USHORT nIndex) const
diff --git a/binfilter/inc/bf_sc/stlpool.hxx b/binfilter/inc/bf_sc/stlpool.hxx
index cd1e0ec..c6ed608 100644
--- a/binfilter/inc/bf_sc/stlpool.hxx
+++ b/binfilter/inc/bf_sc/stlpool.hxx
@@ -67,6 +67,7 @@ public:
void ConvertFontsAfterLoad(); // old binary file format
protected:
+ using SfxStyleSheetPool::Create;
virtual SfxStyleSheetBase* Create( const String& rName,
SfxStyleFamily eFamily,
USHORT nMask);
diff --git a/binfilter/inc/bf_sch/ChXChartDocument.hxx b/binfilter/inc/bf_sch/ChXChartDocument.hxx
index 3d5b1b1..8324b63 100644
--- a/binfilter/inc/bf_sch/ChXChartDocument.hxx
+++ b/binfilter/inc/bf_sch/ChXChartDocument.hxx
@@ -263,6 +263,9 @@ public:
disposing
(const ::com::sun::star::lang::EventObject & Source)
throw (::com::sun::star::uno::RuntimeException);
+
+ using SfxBaseModel::addEventListener;
+ using SfxBaseModel::removeEventListener;
};
} //namespace binfilter
diff --git a/binfilter/inc/bf_sch/axisobj.hxx b/binfilter/inc/bf_sch/axisobj.hxx
index 65b3243..be84513 100644
--- a/binfilter/inc/bf_sch/axisobj.hxx
+++ b/binfilter/inc/bf_sch/axisobj.hxx
@@ -42,6 +42,8 @@ public:
SchAxisObj( ChartModel* = NULL );
+ using SdrObjGroup::operator=;
+
};
class Sch3dAxisObj : public SchE3dObject
@@ -51,6 +53,8 @@ public:
Sch3dAxisObj();
+ using SdrAttrObj::operator=;
+
};
} //namespace binfilter
diff --git a/binfilter/inc/bf_sch/chmod3d.hxx b/binfilter/inc/bf_sch/chmod3d.hxx
index 48491fc..0113f37 100644
--- a/binfilter/inc/bf_sch/chmod3d.hxx
+++ b/binfilter/inc/bf_sch/chmod3d.hxx
@@ -58,6 +58,8 @@ public:
SchE3dLatheObj()
:E3dLatheObj(){};
+ using SdrAttrObj::operator=;
+
virtual void SetItem(const SfxPoolItem& rItem);
virtual void SetItemSet(const SfxItemSet& rSet);
};
@@ -74,6 +76,8 @@ public:
SchE3dExtrudeObj()
:E3dExtrudeObj(){};
+ using SdrAttrObj::operator=;
+
virtual void SetItem(const SfxPoolItem& rItem);
virtual void SetItemSet(const SfxItemSet& rSet);
};
@@ -95,6 +99,8 @@ public:
SchE3dPolygonObj() : E3dPolygonObj(){};
+ using SdrAttrObj::operator=;
+
virtual void SetItem(const SfxPoolItem& rItem);
virtual void SetItemSet(const SfxItemSet& rSet);
};
@@ -107,6 +113,8 @@ class SchE3dObject : public E3dObject
SchE3dObject()
:E3dObject(){};
+ using SdrAttrObj::operator=;
+
virtual void SetItemSet(const SfxItemSet& rSet);
};
class SchRectObj : public SdrRectObj
@@ -116,6 +124,8 @@ public:
:SdrRectObj(eNewTextKind,rRect){};
SchRectObj(const Rectangle& rRect): SdrRectObj(rRect){};
+ using SdrRectObj::operator=;
+
virtual void NbcSetOutlinerParaObject(OutlinerParaObject* pTextObject);
virtual void SetItemSet(const SfxItemSet& rSet);
};
diff --git a/binfilter/inc/bf_sch/chtscene.hxx b/binfilter/inc/bf_sch/chtscene.hxx
index e42dc33..de65463 100644
--- a/binfilter/inc/bf_sch/chtscene.hxx
+++ b/binfilter/inc/bf_sch/chtscene.hxx
@@ -55,6 +55,9 @@ class ChartScene : public E3dPolyScene
TYPEINFO();
ChartScene(ChartModel* pModel);
virtual ~ChartScene();
+
+ using SdrAttrObj::operator=;
+
void Initialize();
virtual Volume3D FitInSnapRect();
diff --git a/binfilter/inc/bf_sch/schgroup.hxx b/binfilter/inc/bf_sch/schgroup.hxx
index ca9fd93..b42c1dd 100644
--- a/binfilter/inc/bf_sch/schgroup.hxx
+++ b/binfilter/inc/bf_sch/schgroup.hxx
@@ -67,7 +67,7 @@ public:
virtual UINT32 GetObjInventor() const;
virtual UINT16 GetObjIdentifier() const;
-
+ using SdrObjGroup::operator=;
// FG: Damit soll erm�glicht werden dass man Objektgruppen im Chart resizen kann
void SetObjInfo(SdrObjTransformInfoRec aMyInfo);
@@ -85,6 +85,7 @@ public:
BOOL GetGroupIsChart() {return (eChartGroupType == DIAGRAM);}
+ using SdrObjGroup::SetModel;
void SetModel (ChartModel *pChModel) {pChartmodel = pChModel; SdrObjGroup::SetModel( (SdrModel*) pChModel ); }
void SetAskForLogicRect(BOOL value) {bAskForLogicRect = value;}
diff --git a/binfilter/inc/bf_sch/stlpool.hxx b/binfilter/inc/bf_sch/stlpool.hxx
index 80835c9..a66016b 100644
--- a/binfilter/inc/bf_sch/stlpool.hxx
+++ b/binfilter/inc/bf_sch/stlpool.hxx
@@ -42,6 +42,7 @@ private:
SfxStyleSheetBase* pActualStyleSheet;
protected:
+ using SfxStyleSheetPool::Create;
virtual SfxStyleSheetBase* Create(const String& rName,
SfxStyleFamily eFamily,
USHORT nMask);
diff --git a/binfilter/inc/bf_sd/stlpool.hxx b/binfilter/inc/bf_sd/stlpool.hxx
index 0bc60b8..004fc37 100644
--- a/binfilter/inc/bf_sd/stlpool.hxx
+++ b/binfilter/inc/bf_sd/stlpool.hxx
@@ -44,6 +44,7 @@ private:
SdDrawDocument* pDoc;
protected:
+ using SfxStyleSheetPool::Create;
virtual SfxStyleSheetBase* Create(const String& rName,
SfxStyleFamily eFamily,
USHORT nMask);
diff --git a/binfilter/inc/bf_sfx2/plugobj.hxx b/binfilter/inc/bf_sfx2/plugobj.hxx
index 2c26d2c..a171ae4 100644
--- a/binfilter/inc/bf_sfx2/plugobj.hxx
+++ b/binfilter/inc/bf_sfx2/plugobj.hxx
@@ -61,6 +61,7 @@ class SfxPluginObject : public SvPlugInObject
#endif
protected:
+ using SvPlugInObject::FillClass;
virtual void FillClass( SvGlobalName * pClassName,
ULONG * pFormat,
String * pAppName,
diff --git a/binfilter/inc/bf_svx/cube3d.hxx b/binfilter/inc/bf_svx/cube3d.hxx
index 4e009a8..092a1e8 100644
--- a/binfilter/inc/bf_svx/cube3d.hxx
+++ b/binfilter/inc/bf_svx/cube3d.hxx
@@ -71,6 +71,8 @@ public:
TYPEINFO();
E3dCubeObj();
+ using SdrAttrObj::operator=;
+
virtual UINT16 GetObjIdentifier() const;
virtual SdrObject* DoConvertToPolyObj(BOOL bBezier) const;
diff --git a/binfilter/inc/bf_svx/dlight3d.hxx b/binfilter/inc/bf_svx/dlight3d.hxx
index 3edd683..d67256f 100644
--- a/binfilter/inc/bf_svx/dlight3d.hxx
+++ b/binfilter/inc/bf_svx/dlight3d.hxx
@@ -64,6 +64,8 @@ class E3dDistantLight : public E3dLight
virtual ~E3dDistantLight();
+ using SdrAttrObj::operator=;
+
virtual UINT16 GetObjIdentifier() const;
virtual bool CalcLighting(Color& rNewColor,
diff --git a/binfilter/inc/bf_svx/editund2.hxx b/binfilter/inc/bf_svx/editund2.hxx
index b45d4ba..4938f03 100644
--- a/binfilter/inc/bf_svx/editund2.hxx
+++ b/binfilter/inc/bf_svx/editund2.hxx
@@ -61,6 +61,7 @@ public:
virtual void Undo() = 0;
virtual void Redo() = 0;
virtual void Repeat() = 0;
+ using SfxUndoAction::Repeat;
virtual String GetComment() const;
virtual USHORT GetId() const;
diff --git a/binfilter/inc/bf_svx/extrud3d.hxx b/binfilter/inc/bf_svx/extrud3d.hxx
index 713f071..b9fc4e1 100644
--- a/binfilter/inc/bf_svx/extrud3d.hxx
+++ b/binfilter/inc/bf_svx/extrud3d.hxx
@@ -72,6 +72,8 @@ public:
E3dExtrudeObj(E3dDefaultAttributes& rDefault, const XPolyPolygon& rXPP, double fDepth);
E3dExtrudeObj();
+ using SdrAttrObj::operator=;
+
// PercentDiagonal: 0..100, before 0.0..0.5
sal_uInt16 GetPercentDiagonal() const
{ return ((const Svx3DPercentDiagonalItem&)GetUnmergedItemSet().Get(SDRATTR_3DOBJ_PERCENT_DIAGONAL)).GetValue(); }
diff --git a/binfilter/inc/bf_svx/label3d.hxx b/binfilter/inc/bf_svx/label3d.hxx
index 45ac927..f21e10c 100644
--- a/binfilter/inc/bf_svx/label3d.hxx
+++ b/binfilter/inc/bf_svx/label3d.hxx
@@ -80,6 +80,8 @@ class E3dLabelObj : public E3dPointObj
virtual ~E3dLabelObj();
+ using SdrAttrObj::operator=;
+
virtual void SetPage(SdrPage* pNewPage);
virtual void SetModel(SdrModel* pNewModel);
diff --git a/binfilter/inc/bf_svx/lathe3d.hxx b/binfilter/inc/bf_svx/lathe3d.hxx
index 019cec9..f9eb206 100644
--- a/binfilter/inc/bf_svx/lathe3d.hxx
+++ b/binfilter/inc/bf_svx/lathe3d.hxx
@@ -73,6 +73,8 @@ class E3dLatheObj : public E3dCompoundObject
E3dLatheObj(E3dDefaultAttributes& rDefault, const PolyPolygon& rPoly);
E3dLatheObj();
+ using SdrAttrObj::operator=;
+
// HorizontalSegments:
sal_Int32 GetHorizontalSegments() const
{ return ((const Svx3DHorizontalSegmentsItem&)GetUnmergedItemSet().Get(SDRATTR_3DOBJ_HORZ_SEGS)).GetValue(); }
diff --git a/binfilter/inc/bf_svx/light3d.hxx b/binfilter/inc/bf_svx/light3d.hxx
index 9481449..c9cd160 100644
--- a/binfilter/inc/bf_svx/light3d.hxx
+++ b/binfilter/inc/bf_svx/light3d.hxx
@@ -67,6 +67,8 @@ class E3dLight : public E3dPointObj
double fLightIntensity = 1.0);
E3dLight();
+ using SdrAttrObj::operator=;
+
virtual UINT16 GetObjIdentifier() const;
virtual bool CalcLighting(Color& rNewColor,
diff --git a/binfilter/inc/bf_svx/obj3d.hxx b/binfilter/inc/bf_svx/obj3d.hxx
index 795f8eb..1bbc16b 100644
--- a/binfilter/inc/bf_svx/obj3d.hxx
+++ b/binfilter/inc/bf_svx/obj3d.hxx
@@ -169,12 +169,14 @@ class E3dObject : public SdrAttrObj
virtual void SetRectsDirty(bool bNotMyself=FALSE);
virtual ~E3dObject();
+ using SdrAttrObj::operator=;
virtual UINT32 GetObjInventor() const;
virtual UINT16 GetObjIdentifier() const;
virtual SdrLayerID GetLayer() const;
+ using SdrObject::GetLayer;
virtual void NbcSetLayer(SdrLayerID nLayer);
virtual void SetObjList(SdrObjList* pNewObjList);
@@ -407,6 +409,8 @@ public :
E3dCompoundObject(E3dDefaultAttributes& rDefault);
virtual ~E3dCompoundObject();
+ using SdrAttrObj::operator=;
+
// DoubleSided: TRUE/FALSE
BOOL GetDoubleSided() const
{ return ((const Svx3DDoubleSidedItem&)GetUnmergedItemSet().Get(SDRATTR_3DOBJ_DOUBLE_SIDED)).GetValue(); }
diff --git a/binfilter/inc/bf_svx/plight3d.hxx b/binfilter/inc/bf_svx/plight3d.hxx
index f82be06..3e44e1a 100644
--- a/binfilter/inc/bf_svx/plight3d.hxx
+++ b/binfilter/inc/bf_svx/plight3d.hxx
@@ -58,6 +58,8 @@ class E3dPointLight : public E3dLight
virtual ~E3dPointLight();
+ using SdrAttrObj::operator=;
+
virtual bool CalcLighting(Color& rNewColor,
const Vector3D& rPnt,
diff --git a/binfilter/inc/bf_svx/pntobj3d.hxx b/binfilter/inc/bf_svx/pntobj3d.hxx
index bce40ae..6f9b3a7 100644
--- a/binfilter/inc/bf_svx/pntobj3d.hxx
+++ b/binfilter/inc/bf_svx/pntobj3d.hxx
@@ -55,6 +55,8 @@ class E3dPointObj : public E3dObject
E3dPointObj(const Vector3D& rPos);
E3dPointObj();
+ using SdrAttrObj::operator=;
+
virtual void SetPosition(const Vector3D& rNewPos);
const Vector3D& GetPosition() const { return aPosition; }
diff --git a/binfilter/inc/bf_svx/polygn3d.hxx b/binfilter/inc/bf_svx/polygn3d.hxx
index b86001b..52fc61a 100644
--- a/binfilter/inc/bf_svx/polygn3d.hxx
+++ b/binfilter/inc/bf_svx/polygn3d.hxx
@@ -65,6 +65,8 @@ public:
E3dPolygonObj();
virtual ~E3dPolygonObj();
+ using SdrAttrObj::operator=;
+
const PolyPolygon3D& GetPolyPolygon3D() const { return aPolyPoly3D; }
const PolyPolygon3D& GetPolyNormals3D() const { return aPolyNormals3D; }
const PolyPolygon3D& GetPolyTexture3D() const { return aPolyTexture3D; }
diff --git a/binfilter/inc/bf_svx/polyob3d.hxx b/binfilter/inc/bf_svx/polyob3d.hxx
index a5498cf..326c4d5 100644
--- a/binfilter/inc/bf_svx/polyob3d.hxx
+++ b/binfilter/inc/bf_svx/polyob3d.hxx
@@ -73,6 +73,7 @@ public:
bool bLight = TRUE);
E3dPolyObj(const Vector3D& rP1, const Vector3D& rP2);
E3dPolyObj();
+ using SdrAttrObj::operator=;
virtual ~E3dPolyObj();
virtual UINT16 GetObjIdentifier() const;
@@ -99,6 +100,7 @@ public:
virtual void RestGeoData(const SdrObjGeoData &rGeo);
virtual void SetPage(SdrPage *pNewPage);
virtual void SetModel(SdrModel *pNewModel);
+ using SdrObject::GetLayer;
virtual SdrLayerID GetLayer() const;
virtual void NbcSetLayer(SdrLayerID nLayer);
virtual SfxStyleSheet *GetStyleSheet() const;
diff --git a/binfilter/inc/bf_svx/polysc3d.hxx b/binfilter/inc/bf_svx/polysc3d.hxx
index 0afe6f8..c0f0b01 100644
--- a/binfilter/inc/bf_svx/polysc3d.hxx
+++ b/binfilter/inc/bf_svx/polysc3d.hxx
@@ -52,6 +52,8 @@ public:
virtual UINT16 GetObjIdentifier() const;
+ using SdrAttrObj::operator=;
+
// Zeichenmethode
virtual bool Paint(ExtOutputDevice&, const SdrPaintInfoRec&) const;
diff --git a/binfilter/inc/bf_svx/scene3d.hxx b/binfilter/inc/bf_svx/scene3d.hxx
index 0aa3a93..b313f65 100644
--- a/binfilter/inc/bf_svx/scene3d.hxx
+++ b/binfilter/inc/bf_svx/scene3d.hxx
@@ -137,6 +137,8 @@ public:
E3dScene();
virtual ~E3dScene();
+ using SdrAttrObj::operator=;
+
// Perspective: enum ProjectionType { PR_PARALLEL, PR_PERSPECTIVE }
ProjectionType GetPerspective() const
{ return (ProjectionType)((const Svx3DPerspectiveItem&)GetUnmergedItemSet().Get(SDRATTR_3DSCENE_PERSPECTIVE)).GetValue(); }
diff --git a/binfilter/inc/bf_svx/sphere3d.hxx b/binfilter/inc/bf_svx/sphere3d.hxx
index 23c62ea..32ce345 100644
--- a/binfilter/inc/bf_svx/sphere3d.hxx
+++ b/binfilter/inc/bf_svx/sphere3d.hxx
@@ -52,6 +52,8 @@ protected:
public:
TYPEINFO();
+ using SdrAttrObj::operator=;
+
// HorizontalSegments:
sal_Int32 GetHorizontalSegments() const
{ return ((const Svx3DHorizontalSegmentsItem&)GetUnmergedItemSet().Get(SDRATTR_3DOBJ_HORZ_SEGS)).GetValue(); }
diff --git a/binfilter/inc/bf_svx/svdocapt.hxx b/binfilter/inc/bf_svx/svdocapt.hxx
index 749dbfb..61bc2c8 100644
--- a/binfilter/inc/bf_svx/svdocapt.hxx
+++ b/binfilter/inc/bf_svx/svdocapt.hxx
@@ -75,6 +75,7 @@ public:
TYPEINFO();
SdrCaptionObj();
virtual ~SdrCaptionObj();
+ using SdrRectObj::operator=;
virtual UINT16 GetObjIdentifier() const;
virtual void RecalcBoundRect();
diff --git a/binfilter/inc/bf_svx/svdocirc.hxx b/binfilter/inc/bf_svx/svdocirc.hxx
index 2c35d8e..d8a1788 100644
--- a/binfilter/inc/bf_svx/svdocirc.hxx
+++ b/binfilter/inc/bf_svx/svdocirc.hxx
@@ -101,6 +101,7 @@ public:
virtual void RecalcSnapRect();
virtual void NbcSetSnapRect(const Rectangle& rRect);
virtual void TakeXorPoly(XPolyPolygon& rXPoly, bool bDetail) const;
+ using SdrObject::TakeContour;
virtual void TakeContour(XPolyPolygon& rXPoly) const;
diff --git a/binfilter/inc/bf_svx/svdoedge.hxx b/binfilter/inc/bf_svx/svdoedge.hxx
index f7ea8e2..6bc82fb 100644
--- a/binfilter/inc/bf_svx/svdoedge.hxx
+++ b/binfilter/inc/bf_svx/svdoedge.hxx
@@ -192,6 +192,7 @@ public:
SdrEdgeObj();
virtual ~SdrEdgeObj();
+ using SdrTextObj::operator=;
SdrObjConnection& GetConnection(bool bTail1) { return *(bTail1 ? &aCon1 : &aCon2); }
virtual UINT16 GetObjIdentifier() const;
diff --git a/binfilter/inc/bf_svx/svdogrp.hxx b/binfilter/inc/bf_svx/svdogrp.hxx
index 79e806b..1782ca1 100644
--- a/binfilter/inc/bf_svx/svdogrp.hxx
+++ b/binfilter/inc/bf_svx/svdogrp.hxx
@@ -146,6 +146,7 @@ public:
// pnPgNum, etc. ist zum schnelleren wiederauffinden gedacht
virtual UINT16 GetObjIdentifier() const;
+ using SdrObject::GetLayer;
virtual SdrLayerID GetLayer() const;
virtual void NbcSetLayer(SdrLayerID nLayer);
virtual void SetObjList(SdrObjList* pNewObjList);
diff --git a/binfilter/inc/bf_svx/svdomeas.hxx b/binfilter/inc/bf_svx/svdomeas.hxx
index 2daa201..7fb7b04 100644
--- a/binfilter/inc/bf_svx/svdomeas.hxx
+++ b/binfilter/inc/bf_svx/svdomeas.hxx
@@ -86,6 +86,7 @@ public:
SdrMeasureObj();
SdrMeasureObj(const Point& rPt1, const Point& rPt2);
virtual ~SdrMeasureObj();
+ using SdrTextObj::operator=;
virtual UINT16 GetObjIdentifier() const;
virtual void TakeUnrotatedSnapRect(Rectangle& rRect) const;
diff --git a/binfilter/inc/bf_svx/svdoole2.hxx b/binfilter/inc/bf_svx/svdoole2.hxx
index 3ad6295..0e6e7e9 100644
--- a/binfilter/inc/bf_svx/svdoole2.hxx
+++ b/binfilter/inc/bf_svx/svdoole2.hxx
@@ -83,6 +83,7 @@ public:
SdrOle2Obj(bool bFrame_=FALSE);
SdrOle2Obj(const SvInPlaceObjectRef& rNewObjRef, const String& rNewObjName, const Rectangle& rNewRect, bool bFrame_=FALSE);
virtual ~SdrOle2Obj();
+ using SdrRectObj::operator=;
// Ein OLE-Zeichenobjekt kann eine StarView-Grafik beinhalten.
// Diese wird angezeigt, wenn das OLE-Objekt leer ist.
diff --git a/binfilter/inc/bf_svx/svdopage.hxx b/binfilter/inc/bf_svx/svdopage.hxx
index f95c812..1941ecf 100644
--- a/binfilter/inc/bf_svx/svdopage.hxx
+++ b/binfilter/inc/bf_svx/svdopage.hxx
@@ -50,6 +50,7 @@ public:
TYPEINFO();
SdrPageObj(USHORT nNewPageNum=0);
~SdrPageObj();
+ using SdrObject::operator=;
virtual void SetModel(SdrModel* pNewModel);
USHORT GetPageNum() const { return nPageNum; }
diff --git a/binfilter/inc/bf_svx/svdopath.hxx b/binfilter/inc/bf_svx/svdopath.hxx
index 1b02d00..e31d27e 100644
--- a/binfilter/inc/bf_svx/svdopath.hxx
+++ b/binfilter/inc/bf_svx/svdopath.hxx
@@ -103,6 +103,7 @@ public:
virtual void RecalcSnapRect();
virtual void NbcSetSnapRect(const Rectangle& rRect);
virtual void TakeContour(XPolyPolygon& rPoly) const;
+ using SdrObject::TakeContour;
virtual void NbcMove(const Size& aSize);
virtual void NbcResize(const Point& rRefPnt, const Fraction& aXFact, const Fraction& aYFact);
diff --git a/binfilter/inc/bf_svx/svdorect.hxx b/binfilter/inc/bf_svx/svdorect.hxx
index 178d4e5..2fd3e87 100644
--- a/binfilter/inc/bf_svx/svdorect.hxx
+++ b/binfilter/inc/bf_svx/svdorect.hxx
@@ -110,6 +110,7 @@ public:
virtual void NbcSetSnapRect(const Rectangle& rRect);
virtual void NbcSetLogicRect(const Rectangle& rRect);
virtual void TakeXorPoly(XPolyPolygon& rPoly, bool bDetail) const;
+ using SdrObject::TakeContour;
virtual void TakeContour(XPolyPolygon& rPoly) const;
diff --git a/binfilter/inc/bf_svx/svdotext.hxx b/binfilter/inc/bf_svx/svdotext.hxx
index 8121424..f21081e 100644
--- a/binfilter/inc/bf_svx/svdotext.hxx
+++ b/binfilter/inc/bf_svx/svdotext.hxx
@@ -310,6 +310,7 @@ public:
virtual void TakeUnrotatedSnapRect(Rectangle& rRect) const;
virtual SdrObject* CheckHit(const Point& rPnt, USHORT nTol, const SetOfByte* pVisiLayer) const;
virtual void operator=(const SdrObject& rObj);
+ using SdrObject::TakeContour;
virtual void TakeContour(XPolyPolygon& rPoly) const;
virtual void RecalcSnapRect();
virtual void NbcSetSnapRect(const Rectangle& rRect);
diff --git a/binfilter/inc/bf_svx/svdouno.hxx b/binfilter/inc/bf_svx/svdouno.hxx
index 35c2d5b..f96714e 100644
--- a/binfilter/inc/bf_svx/svdouno.hxx
+++ b/binfilter/inc/bf_svx/svdouno.hxx
@@ -70,6 +70,7 @@ public:
SdrUnoObj(const String& rModelName, BOOL bOwnsModel = TRUE);
virtual ~SdrUnoObj();
+ using SdrRectObj::operator=;
virtual void SetPage(SdrPage* pNewPage);
virtual void SetModel(SdrModel* pModel);
diff --git a/binfilter/inc/bf_svx/svdovirt.hxx b/binfilter/inc/bf_svx/svdovirt.hxx
index 2643dc5..25a67ea 100644
--- a/binfilter/inc/bf_svx/svdovirt.hxx
+++ b/binfilter/inc/bf_svx/svdovirt.hxx
@@ -62,6 +62,7 @@ public:
TYPEINFO();
SdrVirtObj(SdrObject& rNewObj);
virtual ~SdrVirtObj();
+ using SdrObject::operator=;
virtual SdrObject& ReferencedObj();
virtual const SdrObject& GetReferencedObj() const;
virtual void SetModel(SdrModel* pNewModel);
diff --git a/binfilter/inc/bf_sw/dcontact.hxx b/binfilter/inc/bf_sw/dcontact.hxx
index e11dc63..d17ae96 100644
--- a/binfilter/inc/bf_sw/dcontact.hxx
+++ b/binfilter/inc/bf_sw/dcontact.hxx
@@ -156,6 +156,7 @@ class SwDrawVirtObj : public SdrVirtObj
// OD 30.06.2003 #108784# - virtual!!!
virtual const Point GetOffset() const;
+ using SdrObject::Clone;
virtual SdrObject* Clone() const;
virtual void operator=( const SdrObject& rObj );
@@ -192,6 +193,7 @@ class SwDrawVirtObj : public SdrVirtObj
virtual SdrObject* CheckHit(const Point& rPnt, USHORT nTol, const SetOfByte* pVisiLayer) const;
virtual void TakeXorPoly(XPolyPolygon& rPoly, bool bDetail) const;
virtual void TakeContour(XPolyPolygon& rPoly) const;
+ using SdrObject::TakeContour;
virtual SdrHdl* GetHdl(USHORT nHdlNum) const;
virtual SdrHdl* GetPlusHdl(const SdrHdl& rHdl, USHORT nPlNum) const;
virtual void NbcMove(const Size& rSiz);
@@ -220,6 +222,7 @@ class SwDrawVirtObj : public SdrVirtObj
// OD 17.06.2003 #108784# - overload 'layer' methods
virtual SdrLayerID GetLayer() const;
+ using SdrObject::GetLayer;
virtual void NbcSetLayer(SdrLayerID nLayer);
virtual void SetLayer(SdrLayerID nLayer);
};
More information about the Libreoffice-commits
mailing list
diff --git a/binfilter/inc/bf_svx/unoshape.hxx b/binfilter/inc/bf_svx/unoshape.hxx
index 057b839..368d33f 100644
--- a/binfilter/inc/bf_svx/unoshape.hxx
+++ b/binfilter/inc/bf_svx/unoshape.hxx
@@ -80,7 +80,7 @@ struct SvxShapeImpl;
class SvxShapeMaster;
// WARNING: if you update the supported interfaces, also update the
// SvxShape::queryAggregation helper method
class SvxShape : public cppu::WeakAggImplHelper11<
::com::sun::star::drawing::XShape,
::com::sun::star::lang::XComponent,
@@ -132,7 +132,7 @@ class SvxShape : public cppu::WeakAggImplHelper11<
::com::sun::star::uno::Any GetAnyForItem( SfxItemSet& aSet, const SfxItemPropertyMap* pMap ) const;
- sal_Bool queryAggregation( const ::com::sun::star::uno::Type & rType, ::com::sun::star::uno::Any& rAny );
+ sal_Bool tryQueryAggregation( const ::com::sun::star::uno::Type & rType, ::com::sun::star::uno::Any& rAny );
sal_Bool SAL_CALL SetFillAttribute( sal_Int32 nWID, const ::rtl::OUString& rName );
@@ -80,7 +80,7 @@ struct SvxShapeImpl;
class SvxShapeMaster;
// WARNING: if you update the supported interfaces, also update the
-// SvxShape::queryAggregation helper method
+// SvxShape::tryQueryAggregation helper method
class SvxShape : public cppu::WeakAggImplHelper11<
::com::sun::star::drawing::XShape,